pub struct PipelineTable {
inserter: InserterRef,
statement_executor: StatementExecutorRef,
table: TableRef,
query_engine: QueryEngineRef,
cache: PipelineCache,
}Expand description
PipelineTable is a table that stores the pipeline schema and content. Every catalog has its own pipeline table.
Fields
inserter: InserterRefstatement_executor: StatementExecutorReftable: TableRefquery_engine: QueryEngineRefcache: PipelineCacheImplementations
Sourceimpl PipelineTable
impl PipelineTable
Sourcepub fn new(
inserter: InserterRef,
statement_executor: StatementExecutorRef,
table: TableRef,
query_engine: QueryEngineRef,
) -> Self
pub fn new( inserter: InserterRef, statement_executor: StatementExecutorRef, table: TableRef, query_engine: QueryEngineRef, ) -> Self
Create a new PipelineTable.
Sourcepub fn build_pipeline_schema() -> (String, Vec<String>, Vec<ColumnDef>)
pub fn build_pipeline_schema() -> (String, Vec<String>, Vec<ColumnDef>)
Build the schema for the pipeline table. Returns the (time index, primary keys, column) definitions.
Sourcefn build_insert_column_schemas() -> Vec<PbColumnSchema>
fn build_insert_column_schemas() -> Vec<PbColumnSchema>
Build the column schemas for inserting a row into the pipeline table.
fn query_ctx(table_info: &TableInfo) -> QueryContextRef
Sourcepub fn compile_pipeline(pipeline: &str) -> Result<Pipeline>
pub fn compile_pipeline(pipeline: &str) -> Result<Pipeline>
Compile a pipeline from a string.
Sourceasync fn insert_pipeline_to_pipeline_table(
&self,
name: &str,
content_type: &str,
pipeline: &str,
) -> Result<Timestamp>
async fn insert_pipeline_to_pipeline_table( &self, name: &str, content_type: &str, pipeline: &str, ) -> Result<Timestamp>
Insert a pipeline into the pipeline table.
Sourcepub async fn get_pipeline(
&self,
schema: &str,
name: &str,
input_version: PipelineVersion,
) -> Result<Arc<Pipeline>>
pub async fn get_pipeline( &self, schema: &str, name: &str, input_version: PipelineVersion, ) -> Result<Arc<Pipeline>>
Get a pipeline by name. If the pipeline is not in the cache, it will be get from table and compiled and inserted into the cache.
Sourcepub async fn get_pipeline_str(
&self,
schema: &str,
name: &str,
input_version: PipelineVersion,
) -> Result<PipelineContent>
pub async fn get_pipeline_str( &self, schema: &str, name: &str, input_version: PipelineVersion, ) -> Result<PipelineContent>
Get a original pipeline by name. If the pipeline is not in the cache, it will be get from table and compiled and inserted into the cache.
Sourcepub async fn insert_and_compile(
&self,
name: &str,
content_type: &str,
pipeline: &str,
) -> Result<PipelineInfo>
pub async fn insert_and_compile( &self, name: &str, content_type: &str, pipeline: &str, ) -> Result<PipelineInfo>
Insert a pipeline into the pipeline table and compile it. The compiled pipeline will be inserted into the cache. Newly created pipelines will be saved under empty schema.
pub async fn delete_pipeline( &self, name: &str, version: PipelineVersion, ) -> Result<Option<()>>
async fn find_pipeline( &self, name: &str, version: PipelineVersion, ) -> Result<Vec<PipelineContent>>